@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2006  NTT DATA CORPORATION
  *
- * Version: 1.1.2   2006/06/02
+ * Version: 1.3.1   2006/12/08
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -28,39 +28,67 @@
 #ifndef _LINUX_TOMOYO_H
 #define _LINUX_TOMOYO_H
 
+#ifndef __user
+#define __user
+#endif
+
 /***** TOMOYO Linux start. *****/
 
 #ifdef CONFIG_TOMOYO
 /* Find the next domain to transit to. */
-struct domain_info *GetNextDomain(const char *filename, int *errno);
-char *GetAggregatedProgramName(const char *filename);
+int FindNextDomain(const char *original_name, struct file *filp, struct domain_info **next_domain, char __user * __user *argv);
 #endif
 
 #ifdef CONFIG_TOMOYO_MAC_FOR_FILE
 /* Check whether the given filename is allowed to read/write/execute. */
-int CheckFilePerm(const char *filename, const unsigned short int perm, const int is_realpath, const char *operation);
+int CheckFilePerm(const char *filename, const u16 perm, const char *operation);
+int CheckExecPerm(const char *filename, struct file *filp);
+/* Check whether the given dentry is allowed to read/write/execute. */
+int CheckOpenPermission(struct dentry *dentry, struct vfsmount *mnt, const int flag);
 /* Check whether the given dentry is allowed to write. */
 int CheckSingleWritePermission(const unsigned int operation, struct dentry *dentry, struct vfsmount *mnt);
 int CheckDoubleWritePermission(const unsigned int operation, struct dentry *dentry1, struct vfsmount *mnt1, struct dentry *dentry2, struct vfsmount *mnt2);
+int CheckReWritePermission(struct file *filp);
 #else
-static inline int CheckFilePerm(const char *filename, const unsigned short int perm, const int is_realpath, const char *operation) { return 0; }
+static inline int CheckFilePerm(const char *filename, const u16 perm, const char *operation) { return 0; }
+static inline int CheckExecPerm(const char *filename, struct file *filp) { return 0; }
+static inline int CheckOpenPermission(struct dentry *dentry, struct vfsmount *mnt, const int flag) { return 0; }
 static inline int CheckSingleWritePermission(const unsigned int operation, struct dentry *dentry, struct vfsmount *mnt) { return 0; }
-static inline int CheckDoubleWritePermission(const unsigned int operation, struct dentry *dentry1, struct vfsmount *mnt1, struct dentry *dentry2, struct vfsmount *mnt2) { return 0; };
+static inline int CheckDoubleWritePermission(const unsigned int operation, struct dentry *dentry1, struct vfsmount *mnt1, struct dentry *dentry2, struct vfsmount *mnt2) { return 0; }
+static inline int CheckReWritePermission(struct file *filp) { return 0; }
 #endif
 
-
-/* Check whether the given port number is allowed to bind. */
-#ifdef CONFIG_TOMOYO_MAC_FOR_BINDPORT
-int CheckBindEntry(const int is_stream, const unsigned short int port);
+#ifdef CONFIG_TOMOYO_MAC_FOR_ARGV0
+/* Check whether the basename of program and argv0 is allowed to differ. */
+int CheckArgv0Perm(const char *filename, const char *argv0);
 #else
-static inline int CheckBindEntry(const int is_stream, const unsigned short int port) { return 0; }
+static inline int CheckArgv0Perm(const char *filename, const char *argv0) { return 0; }
 #endif
 
-/* Check whether the given port number is allowed to connect. */
-#ifdef CONFIG_TOMOYO_MAC_FOR_CONNECTPORT
-int CheckConnectEntry(const int is_stream, const unsigned short int port);
+/* Check whether the given port number is allowed to bind or connect. */
+#ifdef CONFIG_TOMOYO_MAC_FOR_NETWORKPORT
+int CheckBindEntry(const int is_stream, const u16 port);
+int CheckConnectEntry(const int is_stream, const u16 port);
 #else
-static inline int CheckConnectEntry(const int is_stream, const unsigned short int port) { return 0; }
+static inline int CheckBindEntry(const int is_stream, const u16 port) { return 0; }
+static inline int CheckConnectEntry(const int is_stream, const u16 port) { return 0; }
+#endif
+
+/* Check whether the given IP address and port number are allowed to use. */
+#ifdef CONFIG_TOMOYO_MAC_FOR_NETWORK
+int CheckNetworkListenACL(const int is_ipv6, const u8 *address, const u16 port);
+int CheckNetworkConnectACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port);
+int CheckNetworkBindACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port);
+int CheckNetworkAcceptACL(const int is_ipv6, const u8 *address, const u16 port);
+int CheckNetworkSendMsgACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port);
+int CheckNetworkRecvMsgACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port);
+#else
+static inline int CheckNetworkListenACL(const int is_ipv6, const u8 *address, const u16 port) { return 0; }
+static inline int CheckNetworkConnectACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port) { return 0; }
+static inline int CheckNetworkBindACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port) { return 0; }
+static inline int CheckNetworkAcceptACL(const int is_ipv6, const u8 *address, const u16 port) { return 0; }
+static inline int CheckNetworkSendMsgACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port) { return 0; }
+static inline int CheckNetworkRecvMsgACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port) { return 0; }
 #endif
 
 /* Check whether the given signal is allowed to use. */
@@ -77,6 +105,7 @@ int CheckCapabilityACL(const unsigned int capability);
 static inline int CheckCapabilityACL(const unsigned int capability) { return 0; }
 #endif
 
+struct inode;
 #include <linux/version.h>
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,5,0)
 int pre_vfs_mknod(struct inode *dir, struct dentry *dentry);
@@ -88,8 +117,8 @@ int pre_vfs_mknod(struct inode *dir, struct dentry *dentry, int mode);
 
 #define MAKE_ACL_TYPE(x)     ((x) << 16)
 #define GET_ACL_TYPE(x)      ((x) >> 16)
-#define MAKE_ACL_HASH(x)     ((x) & 65535)
-#define GET_ACL_HASH(x)      ((x) & 65535)
+#define MAKE_ACL_HASH(x)     ((u16) (x))
+#define GET_ACL_HASH(x)      ((u16) (x))
 #define TYPE_CREATE_ACL       0
 #define TYPE_UNLINK_ACL       1
 #define TYPE_MKDIR_ACL        2
@@ -102,18 +131,19 @@ int pre_vfs_mknod(struct inode *dir, struct dentry *dentry, int mode);
 #define TYPE_SYMLINK_ACL      9
 #define TYPE_LINK_ACL        10
 #define TYPE_RENAME_ACL      11
+#define TYPE_REWRITE_ACL     12
 
-#define TYPE_FILE_ACL       100
-#define TYPE_DIR_ACL        101
-#define TYPE_CAPABILITY_ACL 102
-#define TYPE_SIGNAL_ACL     103
-#define TYPE_CONNECT_ACL    104
-#define TYPE_BIND_ACL       105
+#define TYPE_FILE_ACL         100
+#define TYPE_ARGV0_ACL        101
+#define TYPE_CAPABILITY_ACL   102
+#define TYPE_IPv4_NETWORK_ACL 103
+#define TYPE_IPv6_NETWORK_ACL 104
+#define TYPE_SIGNAL_ACL       105
+#define TYPE_CONNECT_ACL      106
+#define TYPE_BIND_ACL         107
 
 /*************************  Index numbers for Capability Controls.  *************************/
 
-/* The following constants are used for checking capabilities. */
-
 #define TOMOYO_INET_STREAM_SOCKET_CREATE         0  /* socket(PF_INET or PF_INET6, SOCK_STREAM, *)                 */
 #define TOMOYO_INET_STREAM_SOCKET_LISTEN         1  /* listen() for PF_INET or PF_INET6, SOCK_STREAM               */
 #define TOMOYO_INET_STREAM_SOCKET_CONNECT        2  /* connect() for PF_INET or PF_INET6, SOCK_STREAM              */
@@ -142,6 +172,19 @@ int pre_vfs_mknod(struct inode *dir, struct dentry *dentry, int mode);
 #define TOMOYO_SYS_CHMOD                        25  /* sys_chmod(), sys_fchmod()                                   */
 #define TOMOYO_SYS_CHOWN                        26  /* sys_chown(), sys_fchown(), sys_lchown()                     */
 #define TOMOYO_SYS_IOCTL                        27  /* sys_ioctl(), compat_sys_ioctl()                             */
+#define TOMOYO_SYS_KEXEC_LOAD                   28  /* sys_kexec_load()                                            */
+#define TOMOYO_MAX_CAPABILITY_INDEX             29
+
+/*************************  Index numbers for Network Controls.  *************************/
+
+#define NETWORK_ACL_UDP_BIND    0
+#define NETWORK_ACL_UDP_CONNECT 1
+#define NETWORK_ACL_TCP_BIND    2
+#define NETWORK_ACL_TCP_LISTEN  3
+#define NETWORK_ACL_TCP_CONNECT 4
+#define NETWORK_ACL_TCP_ACCEPT  5
+#define NETWORK_ACL_RAW_BIND    6
+#define NETWORK_ACL_RAW_CONNECT 7
 
 /***** TOMOYO Linux end. *****/
 #endif
