@@ -1,3 +1,4 @@
+
 /*
  * fs/proc/ccs_proc.c
  *
@@ -5,7 +6,7 @@
  *
  * Copyright (C) 2005-2006  NTT DATA CORPORATION
  *
- * Version: 1.1.2   2006/06/02
+ * Version: 1.3.1   2006/12/08
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -17,11 +18,19 @@
 #include <asm/io.h>
 #include <linux/proc_fs.h>
 #include <linux/module.h>
+#include <linux/version.h>
 #include <linux/ccs_proc.h>
 #include <linux/ccs_common.h>
 
 #if defined(CONFIG_SAKURA) || defined(CONFIG_TOMOYO)
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,4,23)
+static inline struct proc_dir_entry *PDE(const struct inode *inode)
+{
+	return (struct proc_dir_entry *) inode->u.generic_ip;
+}
+#endif
+
 static int ccs_open(struct inode *inode, struct file *file)
 {
 	return CCS_OpenControl((const int) (PDE(inode)->data), file);
@@ -69,6 +78,8 @@ void __init CCSProc_Init(void)
 	struct proc_dir_entry *ccs_dir = proc_mkdir("ccs", NULL);
 	struct proc_dir_entry *policy_dir = proc_mkdir("policy", ccs_dir),
 		*info_dir = proc_mkdir("info", ccs_dir);
+	extern void __init realpath_Init(void);
+	realpath_Init();
 	CreateEntry("query",            0600, policy_dir, CCS_POLICY_QUERY);
 #ifdef CONFIG_SAKURA
 	CreateEntry("system_policy",    0600, policy_dir, CCS_POLICY_SYSTEMPOLICY);
@@ -76,10 +87,12 @@ void __init CCSProc_Init(void)
 #ifdef CONFIG_TOMOYO
 	CreateEntry("domain_policy",    0600, policy_dir, CCS_POLICY_DOMAINPOLICY);
 	CreateEntry("exception_policy", 0600, policy_dir, CCS_POLICY_EXCEPTIONPOLICY);
-	CreateEntry("trusted_pids",     0400, info_dir, CCS_INFO_TRUSTEDPIDS);
-	CreateEntry("deleted_pids",     0400, info_dir, CCS_INFO_DELETEDPIDS);
+	CreateEntry(".domain_status",   0600, policy_dir, CCS_POLICY_DOMAIN_STATUS);
+	CreateEntry(".process_status",  0400, info_dir, CCS_INFO_PROCESS_STATUS);
+#ifdef CONFIG_TOMOYO_AUDIT
 	CreateEntry("grant_log",        0400, info_dir, CCS_INFO_GRANTLOG);
 	CreateEntry("reject_log",       0400, info_dir, CCS_INFO_REJECTLOG);
+#endif
 	CreateEntry("self_domain",      0400, info_dir, CCS_INFO_SELFDOMAIN);
 #ifdef CONFIG_TOMOYO_MAC_FOR_FILE
 	CreateEntry("mapping",          0400, info_dir, CCS_INFO_MAPPING);
@@ -87,6 +100,8 @@ void __init CCSProc_Init(void)
 #endif
 	CreateEntry("meminfo",          0400, info_dir, CCS_INFO_MEMINFO);
 	CreateEntry("status",           0600, ccs_dir, CCS_STATUS);
+	CreateEntry("manager",          0600, policy_dir, CCS_POLICY_MANAGER);
+	CreateEntry(".updates_counter", 0400, info_dir, CCS_INFO_UPDATESCOUNTER);
 }
 
 #else
